.. _Topology:

Topology
========

Topology objects are used to build JSON representation of network topologies based on information of device neighbors. These classes use the ``get_neighbors()``
function of low-level connection classes, such as :ref:`Cisco_IOS_Cli <Cisco_IOS_Cli>`.



.. autoclass:: nuaal.Discovery.Topology
    :members:
    :private-members:
    :undoc-members:
    :show-inheritance:

CliTopology
===========

.. _CliTopology:

.. autoclass:: nuaal.Discovery.CliTopology
    :members:
    :private-members:
    :undoc-members:
    :show-inheritance:

